@@ -1,7 +1,6 @@
 """Utilities for abstract.py."""
 
 import collections
-import hashlib
 import logging
 from typing import Any, Collection, Dict, Iterable, Mapping, Optional, Sequence, Tuple, Union
 
@@ -391,58 +390,6 @@ def maybe_extract_tuple(t):
   return v.pyval
 
 
-def _hash_dict(vardict, names):
-  """Hash a dictionary.
-
-  This contains the keys and the full hashes of the data in the values.
-
-  Arguments:
-    vardict: A dictionary mapping str to Variable.
-    names: If this is non-None, the snapshot will include only those
-      dictionary entries whose keys appear in names.
-
-  Returns:
-    A hash of the dictionary.
-  """
-  if names is not None:
-    vardict = {name: vardict[name] for name in names.intersection(vardict)}
-  m = hashlib.md5()
-  for name, var in sorted(vardict.items()):
-    m.update(str(name).encode("utf-8"))
-    for value in var.bindings:
-      m.update(value.data.get_fullhash())
-  return m.digest()
-
-
-def hash_all_dicts(*hash_args):
-  """Convenience method for hashing a sequence of dicts."""
-  return hashlib.md5(b"".join(_hash_dict(*args) for args in hash_args)).digest()
-
-
-def _matches_generator(type_obj, allowed_types):
-  """Check if type_obj matches a Generator/AsyncGenerator type."""
-  if _isinstance(type_obj, "Union"):
-    return all(_matches_generator(sub_type, allowed_types)
-               for sub_type in type_obj.options)
-  else:
-    base_cls = type_obj
-    if _isinstance(type_obj, "ParameterizedClass"):
-      base_cls = type_obj.base_cls
-    return ((_isinstance(base_cls, "PyTDClass") and
-             base_cls.name in allowed_types) or
-            _isinstance(base_cls, "AMBIGUOUS_OR_EMPTY"))
-
-
-def matches_generator(type_obj):
-  allowed_types = ("generator", "Iterable", "Iterator")
-  return _matches_generator(type_obj, allowed_types)
-
-
-def matches_async_generator(type_obj):
-  allowed_types = ("asyncgenerator", "AsyncIterable", "AsyncIterator")
-  return _matches_generator(type_obj, allowed_types)
-
-
 def eval_expr(ctx, node, f_globals, f_locals, expr):
   """Evaluate an expression with the given node and globals."""
   # This is used to resolve type comments and late annotations.
@@ -485,28 +432,6 @@ def eval_expr(ctx, node, f_globals, f_locals, expr):
   return ret, e
 
 
-def check_classes(var, check):
-  """Check whether the cls of each value in `var` is a class and passes `check`.
-
-  Args:
-    var: A cfg.Variable or empty.
-    check: (BaseValue) -> bool.
-
-  Returns:
-    Whether the check passes.
-  """
-  if not var:
-    return False
-  for v in var.data:
-    if _isinstance(v, "Class"):
-      if not check(v):
-        return False
-    elif _isinstance(v.cls, "Class") and v.cls != v:
-      if not check(v.cls):
-        return False
-  return True
-
-
 def match_type_container(typ, container_type_name: Union[str, Tuple[str, ...]]):
   """Unpack the type parameter from ContainerType[T]."""
   if typ is None:
@@ -588,12 +513,6 @@ class Local:
       return None
 
 
-def is_literal(annot: Optional[_BaseValue]):
-  if _isinstance(annot, "Union"):
-    return all(is_literal(o) for o in annot.options)  # pytype: disable=attribute-error
-  return _isinstance(annot, "LiteralClass")
-
-
 def is_concrete_dict(val: _BaseValue):
   return _isinstance(val, "Dict") and not val.could_contain_anything
 
@@ -806,15 +725,16 @@ def maybe_unwrap_decorated_function(func):
   return func.func
 
 
+# The _isinstance and _make methods should be used only in pytype.abstract
+# submodules that are unable to reference abstract.py classes due to circular
+# dependencies. To prevent accidental misuse, the methods are marked private.
+# Callers are expected to alias them like so:
+#   _isinstance = abstract_utils._isinstance  # pylint: disable=protected-access
+
+
 def _isinstance(obj, name_or_names):
   """Do an isinstance() call for a class defined in pytype.abstract.
 
-  This method should be used only in pytype.abstract submodules that are unable
-  to do normal isinstance() checks on abstract values due to circular
-  dependencies. To prevent accidental misuse, this method is marked private.
-  Callers are expected to alias it like so:
-    _isinstance = abstract_utils._isinstance  # pylint: disable=protected-access
-
   Args:
     obj: An instance.
     name_or_names: A name or tuple of names of classes in pytype.abstract.
@@ -840,3 +760,13 @@ def _isinstance(obj, name_or_names):
   name = names[0]
   return any(cls.__module__.startswith("pytype.abstract.") and
              cls.__name__ == name for cls in obj.__class__.mro())
+
+
+def _make(cls_name, *args, **kwargs):
+  """Make an instance of cls_name with the given arguments."""
+  from pytype.abstract import abstract  # pylint: disable=g-import-not-at-top  # pytype: disable=import-error
+  return getattr(abstract, cls_name)(*args, **kwargs)
+
+
+def is_recursive_annotation(annot):
+  return annot.is_late_annotation() and annot.is_recursive()
