@@ -13,6 +13,7 @@ from pytype.pytd import pytd
 
 log = logging.getLogger(__name__)
 _isinstance = abstract_utils._isinstance  # pylint: disable=protected-access
+_make = abstract_utils._make  # pylint: disable=protected-access
 
 
 # Classes have a metadata dictionary that can store arbitrary metadata for
@@ -291,6 +292,11 @@ class Class(metaclass=mixin.MixinMeta):  # pylint: disable=undefined-variable
   def is_protocol(self):
     return bool(self.protocol_attributes)
 
+  @property
+  def is_typed_dict_class(self):
+    return (self.full_name == "typing.TypedDict" or
+            self.__class__.__name__ == "TypedDictClass")
+
   def _get_inherited_metaclass(self):
     for base in self.mro[1:]:
       if (isinstance(base, Class) and
@@ -392,8 +398,7 @@ class Class(metaclass=mixin.MixinMeta):  # pylint: disable=undefined-variable
       key = node
     assert key
     if key not in self._instance_cache:
-      self._instance_cache[key] = self.ctx.abstract_classes_for_submodules[
-          "Instance"].from_value(self, container)
+      self._instance_cache[key] = _make("Instance", self, self.ctx, container)
     return self._instance_cache[key]
 
   def _check_not_instantiable(self):
@@ -401,7 +406,8 @@ class Class(metaclass=mixin.MixinMeta):  # pylint: disable=undefined-variable
     # We report a not-instantiable error if all of the following are true:
     # - The class is abstract.
     # - It was not created from an explicit type annotation.
-    # - The instantiation is not occuring inside one of the class's own methods.
+    # - The instantiation is not occurring inside one of the class's own
+    #   methods.
     # We check the last condition by seeing whether ctx.vm.frame.func is an
     # InterpreterFunction whose name starts with "<class>."
     if not self.is_abstract or self.from_annotation:
@@ -437,8 +443,7 @@ class Class(metaclass=mixin.MixinMeta):  # pylint: disable=undefined-variable
       # Treat this class as a parameterized container in an annotation. We do
       # not need to worry about the class not being a container: in that case,
       # AnnotationContainer's param length check reports an appropriate error.
-      container = self.ctx.abstract_classes_for_submodules[
-          "AnnotationContainer"].from_value(self)
+      container = self.to_annotation_container()
       return container.get_special_attribute(node, name, valself)
     return Class.super(self.get_special_attribute)(node, name, valself)
 
