@@ -10,7 +10,6 @@ from pytype import special_builtins
 from pytype import utils
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
-from pytype.abstract import class_mixin
 from pytype.abstract import function
 from pytype.abstract import mixin
 from pytype.overlays import attr_overlay
@@ -262,10 +261,6 @@ class Converter(utils.ContextWeakrefMixin):
     """Create an empty VM dict."""
     return abstract.Dict(self.ctx).to_variable(node)
 
-  def build_map_class(self, node, type_params):
-    assert set(type_params) == {abstract_utils.K, abstract_utils.V}
-    return abstract.ParameterizedClass(self.dict_type, type_params, self.ctx)
-
   def build_tuple(self, node, content):
     """Create a VM tuple from the given sequence."""
     return self.tuple_to_value(content).to_variable(node)
@@ -313,20 +308,10 @@ class Converter(utils.ContextWeakrefMixin):
     self.ctx.vm.trace_unknown(unknown.class_name, val)
     return v
 
-  def create_new_varargs_value(self, arg_type):
-    """Create a varargs argument given its element type."""
-    params = {abstract_utils.T: arg_type}
-    return abstract.ParameterizedClass(self.tuple_type, params, self.ctx)
-
-  def create_new_kwargs_value(self, arg_type):
-    """Create a kwargs argument given its element type."""
-    params = {abstract_utils.K: self.str_type, abstract_utils.V: arg_type}
-    return abstract.ParameterizedClass(self.dict_type, params, self.ctx)
-
   def get_element_type(self, arg_type):
     """Extract the element type of a vararg or kwarg."""
     if not isinstance(arg_type, abstract.ParameterizedClass):
-      assert (isinstance(arg_type, class_mixin.Class) and
+      assert (isinstance(arg_type, abstract.Class) and
               arg_type.full_name in ("builtins.dict", "builtins.tuple"))
       return None
     elif arg_type.base_cls is self.dict_type:
@@ -342,7 +327,7 @@ class Converter(utils.ContextWeakrefMixin):
                                          old_container.formal_type_parameters,
                                          self.ctx)
     else:
-      assert isinstance(old_container, class_mixin.Class)
+      assert isinstance(old_container, abstract.Class)
       return new_container
 
   def widen_type(self, container):
@@ -435,7 +420,7 @@ class Converter(utils.ContextWeakrefMixin):
     result = self.constant_to_value(pyval, subst, node)
     if result is not None:
       return result.to_variable(node)
-    # There might still be bugs on the abstract intepreter when it returns,
+    # There might still be bugs on the abstract interpreter when it returns,
     # e.g. a list of values instead of a list of types:
     assert pyval.__class__ != cfg.Variable, pyval
     if pyval.__class__ == tuple:
@@ -498,6 +483,12 @@ class Converter(utils.ContextWeakrefMixin):
         #     # visible inside the "if", is used, which will eventually lead
         #     # pytype to think that the V->complex binding isn't visible.
         #     d = {"a": 1j}
+        if (self.ctx.options.allow_recursive_types and
+            isinstance(pyval, pytd.LateType)):
+          annot = abstract.LateAnnotation(
+              pyval.name, self.ctx.vm.frames, self.ctx)  # pytype: disable=attribute-error
+          annot.set_type(value)
+          value = annot
         self._convert_cache[key] = value
       return value
 
@@ -810,7 +801,7 @@ class Converter(utils.ContextWeakrefMixin):
         base = pyval.base_type.cls
       assert isinstance(base, pytd.Class), base
       base_cls = self.constant_to_value(base, subst, self.ctx.root_node)
-      if not isinstance(base_cls, class_mixin.Class):
+      if not isinstance(base_cls, abstract.Class):
         # base_cls can be, e.g., an unsolvable due to an mro error.
         return self.unsolvable
       if isinstance(pyval, pytd.TupleType):
