@@ -7,15 +7,17 @@ import io
 import logging
 import re
 import sys
-from typing import Iterable, Optional, Union
+import typing
+from typing import Callable, Iterable, Optional, Sequence, TypeVar, Union
 
 from pytype import debug
 from pytype import matcher
 from pytype import utils
 from pytype.abstract import abstract
 from pytype.abstract import abstract_utils
-from pytype.abstract import class_mixin
 from pytype.abstract import function
+from pytype.abstract import mixin
+from pytype.overlays import typed_dict as typed_dict_overlay
 from pytype.pytd import escape
 from pytype.pytd import optimize
 from pytype.pytd import pytd_utils
@@ -48,8 +50,10 @@ TRACEBACK_MARKER = "Called from (traceback):"
 # Symbol representing an elided portion of the stack.
 _ELLIPSIS = object()
 
+_FuncT = TypeVar("_FuncT", bound=Callable)
 
-def _error_name(name):
+
+def _error_name(name) -> Callable[[_FuncT], _FuncT]:
   """Decorate a function so that it binds the current error name."""
   _ERROR_NAMES.add(name)
   def wrap(func):
@@ -493,15 +497,19 @@ class ErrorLog(ErrorLogBase):
   def _print_as_expected_type(self, t: abstract.BaseValue, instance=None):
     """Print abstract value t as a pytd type."""
     if t.is_late_annotation():
-      return t.expr
+      return typing.cast(abstract.LateAnnotation, t).expr
+    elif isinstance(t, abstract.Union):
+      return self._join_printed_types(self._print_as_expected_type(o)
+                                      for o in t.options)
     elif isinstance(t, (abstract.Unknown, abstract.Unsolvable,
-                        class_mixin.Class, abstract.Union)):
+                        abstract.Class)):
       with t.ctx.pytd_convert.set_output_mode(
           t.ctx.pytd_convert.OutputMode.DETAILED):
         return self._pytd_print(t.get_instance_type(instance=instance))
     elif abstract_utils.is_concrete(t):
       return re.sub(r"(\\n|\s)+", " ",
-                    t.str_of_constant(self._print_as_expected_type))
+                    typing.cast(mixin.PythonConstant, t).str_of_constant(
+                        self._print_as_expected_type))
     elif isinstance(t, abstract.AnnotationClass) or t.cls == t:
       return t.name
     else:
@@ -529,13 +537,15 @@ class ErrorLog(ErrorLogBase):
     convert = formal.ctx.pytd_convert
     with convert.set_output_mode(convert.OutputMode.DETAILED):
       expected = self._pytd_print(formal.get_instance_type(node))
+      if isinstance(formal, typed_dict_overlay.TypedDictClass):
+        expected = expected + "(TypedDict)"
     if "Literal[" in expected:
       output_mode = convert.OutputMode.LITERAL
     else:
       output_mode = convert.OutputMode.DETAILED
     with convert.set_output_mode(output_mode):
       bad_actual = self._pytd_print(pytd_utils.JoinTypes(
-          view[actual].data.to_type(node, view=view) for view, _, _ in bad))
+          view[actual].data.to_type(node, view=view) for view, _ in bad))
       if len(actual.bindings) > len(bad):
         full_actual = self._pytd_print(pytd_utils.JoinTypes(
             v.to_type(node) for v in actual.data))
@@ -543,9 +553,8 @@ class ErrorLog(ErrorLogBase):
         full_actual = bad_actual
     # typing.NoReturn is a prettier alias for nothing.
     fmt = lambda ret: "NoReturn" if ret == "nothing" else ret
-    protocol_details, nis_details = self._prepare_errorlog_details(bad)
-    return (fmt(expected), fmt(bad_actual), fmt(full_actual), protocol_details,
-            nis_details)
+    error_details = self._prepare_errorlog_details(bad)
+    return (fmt(expected), fmt(bad_actual), fmt(full_actual), error_details)
 
   def _print_as_function_def(self, fn):
     assert isinstance(fn, abstract.Function)
@@ -582,32 +591,74 @@ class ErrorLog(ErrorLogBase):
                 f"wrong type in {left}: expected {expected}, got {actual}")
 
   def _print_noniterable_str_error(self, error):
+    """Pretty-print the matcher.NonIterableStrError instance."""
     return (
         f"Note: {error.left_type.name} does not match iterables by default. "
         "Learn more: https://github.com/google/pytype/blob/main/docs/faq.md#why-doesnt-str-match-against-string-iterables")
 
-  def _prepare_errorlog_details(self, bad):
-    protocol_details = set()
-    nis_details = set()
-    for _, protocol_err, nis_err in bad:
-      if protocol_err:
-        protocol_details.add("\n" + self._print_protocol_error(protocol_err))
-      if nis_err:
-        nis_details.add("\n" + self._print_noniterable_str_error(nis_err))
+  def _print_typed_dict_error(self, error):
+    """Pretty-print the matcher.TypedDictError instance."""
+    ret = ""
+    if error.missing:
+      ret += "\nTypedDict missing keys: " + ", ".join(error.missing)
+    if error.extra:
+      ret += "\nTypedDict extra keys: " + ", ".join(error.extra)
+    if error.bad:
+      ret += "\nTypedDict type errors: "
+      for k, v, typ, bad in error.bad:
+        for view, _ in bad:
+          actual = self._print_as_actual_type(view[v].data)
+          expected = self._print_as_expected_type(typ)
+          ret += f"\n  {{'{k}': ...}}: expected {expected}, got {actual}"
+    return ret
 
-    return sorted(protocol_details), sorted(nis_details)
+  def _print_error_details(self, error_details):
+    printers = [
+        (error_details.protocol, self._print_protocol_error),
+        (error_details.noniterable_str, self._print_noniterable_str_error),
+        (error_details.typed_dict, self._print_typed_dict_error)
+    ]
+    return ["\n" + printer(err) if err else "" for err, printer in printers]
+
+  def _prepare_errorlog_details(self, bad):
+    """Prepare printable annotation matching errors."""
+    details = collections.defaultdict(set)
+    for _, err in bad:
+      d = self._print_error_details(err)
+      for i, detail in enumerate(d):
+        if detail:
+          details[i].add(detail)
+    ret = []
+    for i in sorted(details.keys()):
+      ret.extend(sorted(details[i]))
+    return ret
 
   def _join_printed_types(self, types):
     """Pretty-print the union of the printed types."""
-    types = sorted(set(types))  # dedup
+    types = set(types)  # dedup
     if len(types) == 1:
       return next(iter(types))
     elif types:
-      if "None" in types:
-        types.remove("None")
-        return "Optional[%s]" % self._join_printed_types(types)
+      literal_contents = set()
+      optional = False
+      new_types = []
+      for t in types:
+        if t.startswith("Literal["):
+          literal_contents.update(t[len("Literal["):-1].split(", "))
+        elif t == "None":
+          optional = True
+        else:
+          new_types.append(t)
+      if literal_contents:
+        literal = "Literal[%s]" %", ".join(sorted(literal_contents))
+        new_types.append(literal)
+      if len(new_types) > 1:
+        out = "Union[%s]" % ", ".join(sorted(new_types))
       else:
-        return "Union[%s]" % ", ".join(types)
+        out = new_types[0]
+      if optional:
+        out = "Optional[%s]" % out
+      return out
     else:
       return "nothing"
 
@@ -743,11 +794,8 @@ class ErrorLog(ErrorLogBase):
         "       Expected: (", expected, ")\n",
         "Actually passed: (", actual,
         ")"])
-    if bad_param and bad_param.protocol_error:
-      details += "\n" + self._print_protocol_error(bad_param.protocol_error)
-    if bad_param and bad_param.noniterable_str_error:
-      details += "\n" + self._print_noniterable_str_error(
-          bad_param.noniterable_str_error)
+    if bad_param and bad_param.error_details:
+      details += "".join(self._print_error_details(bad_param.error_details))
     self.error(stack, message, details, bad_call=bad_call)
 
   @_error_name("wrong-arg-count")
@@ -899,7 +947,7 @@ class ErrorLog(ErrorLogBase):
   @_error_name("bad-return-type")
   def bad_return_type(self, stack, node, formal, actual, bad):
     """Logs a [bad-return-type] error."""
-    expected, bad_actual, full_actual, protocol_details, nis_details = (
+    expected, bad_actual, full_actual, error_details = (
         self._print_as_return_types(node, formal, actual, bad))
     if full_actual == bad_actual:
       message = "bad return type"
@@ -907,7 +955,7 @@ class ErrorLog(ErrorLogBase):
       message = f"bad option {bad_actual!r} in return type"
     details = ["         Expected: ", expected, "\n",
                "Actually returned: ", full_actual]
-    details.extend(protocol_details + nis_details)
+    details.extend(error_details)
     self.error(stack, message, "".join(details))
 
   @_error_name("bad-yield-annotation")
@@ -923,13 +971,13 @@ class ErrorLog(ErrorLogBase):
 
   @_error_name("bad-concrete-type")
   def bad_concrete_type(self, stack, node, formal, actual, bad, details=None):
-    expected, actual, _, protocol_details, nis_details = (
+    expected, actual, _, error_details = (
         self._print_as_return_types(node, formal, actual, bad))
     full_details = ["       Expected: ", expected, "\n",
                     "Actually passed: ", actual]
     if details:
       full_details.append("\n" + details)
-    full_details.extend(protocol_details + nis_details)
+    full_details.extend(error_details)
     self.error(
         stack, "Invalid instantiation of generic class", "".join(full_details))
 
@@ -977,6 +1025,29 @@ class ErrorLog(ErrorLogBase):
       annot = self._print_as_expected_type(annot)
     self._invalid_annotation(stack, annot, details, name)
 
+  def _print_params_helper(self, param_or_params):
+    if isinstance(param_or_params, abstract.BaseValue):
+      return self._print_as_expected_type(param_or_params)
+    else:
+      return "[%s]" % ", ".join(
+          self._print_params_helper(p) for p in param_or_params)
+
+  def wrong_annotation_parameter_count(
+      self, stack, annot: abstract.BaseValue,
+      params: Sequence[abstract.BaseValue], expected_count: int,
+      template: Optional[Iterable[str]] = None):
+    """Log an error for an annotation with the wrong number of parameters."""
+    base_type = self._print_as_expected_type(annot)
+    full_type = base_type + self._print_params_helper(params)
+    if template:
+      templated_type = "%s[%s]" % (base_type, ", ".join(template))
+    else:
+      templated_type = base_type
+    details = "%s expected %d parameter%s, got %d" % (
+        templated_type, expected_count, "" if expected_count == 1 else "s",
+        len(params))
+    self._invalid_annotation(stack, full_type, details, name=None)
+
   def invalid_ellipses(self, stack, indices, container_name):
     if indices:
       details = "Not allowed at %s %s in %s" % (
@@ -1139,20 +1210,20 @@ class ErrorLog(ErrorLogBase):
 
   @_error_name("annotation-type-mismatch")
   def annotation_type_mismatch(
-      self, stack, annot, binding, name, protocol_err, nis_err, details=None):
+      self, stack, annot, binding, name, error_details, details=None, *,
+      typed_dict=None):
     """Invalid combination of annotation and assignment."""
     if annot is None:
       return
     annot_string = self._print_as_expected_type(annot)
+    if isinstance(annot, typed_dict_overlay.TypedDictClass):
+      annot_string = annot_string + "(TypedDict)"
     literal = "Literal[" in annot_string
     actual_string = self._print_as_actual_type(binding.data, literal=literal)
     if actual_string == "None":
       annot_string += f" (Did you mean 'typing.Optional[{annot_string}]'?)"
     additional_details = f"\n\n{details}" if details else ""
-    if protocol_err:
-      additional_details += "\n" + self._print_protocol_error(protocol_err)
-    if nis_err:
-      additional_details += "\n" + self._print_noniterable_str_error(nis_err)
+    additional_details += "".join(self._print_error_details(error_details))
     details = ("Annotation: %s\n" % annot_string +
                "Assignment: %s" % actual_string +
                additional_details)
@@ -1165,8 +1236,13 @@ class ErrorLog(ErrorLogBase):
       if len(print_types) > 1:
         details += "\nIn assignment of type: %s" % self._join_printed_types(
             print_types)
-    suffix = "" if name is None else " for " + name
-    err_msg = "Type annotation%s does not match type of assignment" % suffix
+    if typed_dict is not None:
+      suffix = f" for key {name} in TypedDict {typed_dict.class_name}"
+    elif name is not None:
+      suffix = " for " + name
+    else:
+      suffix = ""
+    err_msg = f"Type annotation{suffix} does not match type of assignment"
     self.error(stack, err_msg, details=details)
 
   @_error_name("container-type-mismatch")
@@ -1211,6 +1287,21 @@ class ErrorLog(ErrorLogBase):
     """Invalid function constructed via metaprogramming."""
     self.error(stack, msg)
 
+  @_error_name("typed-dict-error")
+  def typed_dict_error(self, stack, obj, name):
+    """Accessing a nonexistent key in a typed dict.
+
+    Args:
+      stack: the frame stack
+      obj: the typed dict instance
+      name: the key name
+    """
+    if name:
+      err_msg = f"TypedDict {obj.class_name} does not contain key {name}"
+    else:
+      err_msg = f"TypedDict {obj.class_name} requires all keys to be strings"
+    self.error(stack, err_msg)
+
 
 def get_error_names_set():
   return _ERROR_NAMES
