@@ -13,9 +13,7 @@ import contextlib
 import struct
 import sys
 
-from pytype import compat
-import six
-import six.moves
+from pytype import utils
 
 
 TYPE_NULL = 0x30  # '0'
@@ -182,7 +180,7 @@ class _LoadMarshal:
     """Read an unsigned byte."""
     pos = self.bufpos
     self.bufpos += 1
-    return six.indexbytes(self.bufstr, pos)
+    return self.bufstr[pos]
 
   def _read_short(self):
     """Read a signed 16 bit word."""
@@ -197,7 +195,7 @@ class _LoadMarshal:
   def _read_long(self):
     """Read a signed 32 bit word."""
     s = self._read(4)
-    b = lambda i: six.indexbytes(s, i)
+    b = lambda i: s[i]
     x = b(0) | b(1)<<8 | b(2)<<16 | b(3)<<24
     if b(3) & 0x80 and x > 0:
       # sign extension
@@ -209,7 +207,7 @@ class _LoadMarshal:
   def _read_long64(self):
     """Read a signed 64 bit integer."""
     s = self._read(8)
-    b = lambda i: six.indexbytes(s, i)
+    b = lambda i: s[i]
     x = (b(0) | b(1)<<8 | b(2)<<16 | b(3)<<24 |
          b(4)<<32 | b(5)<<40 | b(6)<<48 | b(7)<<56)
     if b(7) & 0x80 and x > 0:
@@ -262,7 +260,7 @@ class _LoadMarshal:
     """Load a variable length integer."""
     size = self._read_long()
     x = 0
-    for i in six.moves.range(abs(size)):
+    for i in range(abs(size)):
       d = self._read_short()
       x |= d<<(i*15)
     return x if size >= 0 else -x
@@ -291,23 +289,13 @@ class _LoadMarshal:
 
   def load_string(self):
     n = self._read_long()
-    s = self._read(n)
-    if self.python_version[0] >= 3:
-      # load_string() loads a bytestring, and in Python 3, str and bytes are
-      # different classes.
-      s = compat.BytesType(s)
-    elif not self._keep_bytes:
-      # In Python 2, load_string is used to load both bytestrings and native
-      # strings, so we have to specify which we want. We use the
-      # 'backslashreplace' error mode in order to handle non-utf8
-      # backslash-escaped string literals correctly.
-      s = compat.native_str(s, 'backslashreplace')
+    s = bytes(self._read(n))
     return s
 
   def load_interned(self):
     n = self._read_long()
     s = self._read(n)
-    ret = six.moves.intern(compat.native_str(s))
+    ret = sys.intern(utils.native_str(s))
     self._stringtable.append(ret)
     return ret
 
@@ -318,28 +306,19 @@ class _LoadMarshal:
   def load_unicode(self):
     n = self._read_long()
     s = self._read(n)
-    # We need to convert bytes to a unicode string for any of the following:
-    # - We are analysing python2 code
-    # - We are running in a python3 host
-    # If we are analysing python3 code in a python2 host, we leave the string as
-    # a utf-8 encoded bytestring.
-    if (self.python_version[0] < 3 or
-        sys.version_info[0] == 3):
-      # We use the 'backslashreplace' error mode in order to handle non-utf8
-      # backslash-escaped string literals correctly.
-      s = s.decode('utf8', 'backslashreplace')
-    if self.python_version[0] < 3:
-      # In Python 2, unicode and str are different classes.
-      s = compat.UnicodeType(s)
+    # We need to convert bytes to a unicode string.
+    # We use the 'backslashreplace' error mode in order to handle non-utf8
+    # backslash-escaped string literals correctly.
+    s = s.decode('utf8', 'backslashreplace')
     return s
 
   def load_ascii(self):
     n = self._read_long()
-    return compat.native_str(self._read(n))
+    return utils.native_str(self._read(n))
 
   def load_short_ascii(self):
     n = self._read_byte()
-    return compat.native_str(self._read(n))
+    return utils.native_str(self._read(n))
 
   def load_tuple(self):
     return tuple(self.load_list())
@@ -347,14 +326,14 @@ class _LoadMarshal:
   def load_small_tuple(self):
     n = self._read_byte()
     l = []
-    for _ in six.moves.range(n):
+    for _ in range(n):
       l.append(self.load())
     return tuple(l)
 
   def load_list(self):
     n = self._read_long()
     l = []
-    for _ in six.moves.range(n):
+    for _ in range(n):
       l.append(self.load())
     return l
 
@@ -407,12 +386,12 @@ class _LoadMarshal:
 
   def load_set(self):
     n = self._read_long()
-    args = [self.load() for _ in six.moves.range(n)]
+    args = [self.load() for _ in range(n)]
     return set(args)
 
   def load_frozenset(self):
     n = self._read_long()
-    args = [self.load() for _ in six.moves.range(n)]
+    args = [self.load() for _ in range(n)]
     return frozenset(args)
 
   def load_ref(self):
