@@ -1,5 +1,6 @@
 """Function definitions in pyi files."""
 
+import sys
 import textwrap
 
 from typing import Any, List, Optional
@@ -11,7 +12,12 @@ from pytype.pytd import pytd
 from pytype.pytd import visitors
 from pytype.pytd.codegen import function as pytd_function
 
-from typed_ast import ast3
+# pylint: disable=g-import-not-at-top
+if sys.version_info >= (3, 8):
+  import ast as ast3
+else:
+  from typed_ast import ast3
+# pylint: enable=g-import-not-at-top
 
 
 class Mutator(visitors.Visitor):
@@ -52,7 +58,7 @@ class Param(pytd_function.Param):
   """Internal representation of function parameters."""
 
   @classmethod
-  def from_arg(cls, arg: ast3.AST, kwonly=False) -> "Param":
+  def from_arg(cls, arg: ast3.arg, kwonly=False) -> "Param":
     """Constructor from an ast.argument node."""
     p = cls(arg.arg)
     if arg.annotation:
@@ -65,7 +71,8 @@ class NameAndSig(pytd_function.NameAndSig):
   """Internal representation of function signatures."""
 
   @classmethod
-  def from_function(cls, function: ast3.AST, is_async: bool) -> "NameAndSig":
+  def from_function(
+      cls, function: ast3.FunctionDef, is_async: bool) -> "NameAndSig":
     """Constructor from an ast.FunctionDef node."""
     name = function.name
 
@@ -131,7 +138,7 @@ class NameAndSig(pytd_function.NameAndSig):
 
 
 def _pytd_signature(
-    function: ast3.AST,
+    function: ast3.FunctionDef,
     is_async: bool,
     exceptions: Optional[List[pytd.Type]] = None
 ) -> pytd.Signature:
@@ -155,14 +162,15 @@ def _pytd_signature(
                         exceptions=tuple(exceptions), template=())
 
 
-def _pytd_star_param(arg: ast3.AST) -> Optional[pytd.Parameter]:
+def _pytd_star_param(arg: ast3.arg) -> Optional[pytd.Parameter]:
   """Return a pytd.Parameter for a *args argument."""
   if not arg:
     return None
   return pytd_function.pytd_star_param(arg.arg, arg.annotation)
 
 
-def _pytd_starstar_param(arg: ast3.AST) -> Optional[pytd.Parameter]:
+def _pytd_starstar_param(
+    arg: Optional[ast3.arg]) -> Optional[pytd.Parameter]:
   """Return a pytd.Parameter for a **kwargs argument."""
   if not arg:
     return None
@@ -173,7 +181,7 @@ def _apply_defaults(params: List[Param], defaults: List[Any]) -> None:
   for p, d in zip(reversed(params), reversed(defaults)):
     if d is None:
       continue
-    elif isinstance(d, types.Constant):
+    elif isinstance(d, types.Pyval):
       p.default = d.to_pytd()
     else:
       p.default = pytd.AnythingType()
