@@ -1,10 +1,17 @@
 """Base visitor for typed_ast parse trees."""
 
+import sys
+
 from pytype.ast import visitor as ast_visitor
 from pytype.pyi import types
 from pytype.pyi.types import ParseError  # pylint: disable=g-importing-member
 
-from typed_ast import ast3
+# pylint: disable=g-import-not-at-top
+if sys.version_info >= (3, 8):
+  import ast as ast3
+else:
+  from typed_ast import ast3
+# pylint: enable=g-import-not-at-top
 
 
 class BaseVisitor(ast_visitor.BaseVisitor):
@@ -45,20 +52,25 @@ class BaseVisitor(ast_visitor.BaseVisitor):
   def visit_Ellipsis(self, node):
     return self.defs.ELLIPSIS
 
+  def visit_Constant(self, node):
+    if node.value is Ellipsis:
+      return self.defs.ELLIPSIS
+    return types.Pyval.from_const(node)
+
   def visit_NameConstant(self, node):
-    return types.Constant.from_const(node)
+    return types.Pyval.from_const(node)
 
   def visit_Num(self, node):
-    return types.Constant.from_num(node)
+    return types.Pyval.from_num(node)
 
   def visit_Str(self, node):
-    return types.Constant.from_str(node)
+    return types.Pyval.from_str(node)
 
   def visit_Bytes(self, node):
     return self.visit_Str(node)
 
   def visit_UnaryOp(self, node):
     if isinstance(node.op, ast3.USub):
-      if isinstance(node.operand, types.Constant):
+      if isinstance(node.operand, types.Pyval):
         return node.operand.negated()
     raise ParseError(f"Unexpected unary operator: {node.op}")
