@@ -4,7 +4,7 @@ from typing import Dict, TypeVar
 _KT = TypeVar('_KT')
 _VT = TypeVar('_VT')
 
-class UserDict(object):
+class UserDict:
     def __init__(self, initialdata = None):
         # type: (Dict[_KT, _VT]) -> None
         pass
