@@ -3,8 +3,9 @@
 #ifndef PYTYPE_TYPEGRAPH_REACHABLE_H_
 #define PYTYPE_TYPEGRAPH_REACHABLE_H_
 
-#include <vector>
+#include <cstddef>
 #include <cstdint>
+#include <vector>
 
 namespace devtools_python_typegraph {
 
@@ -16,12 +17,12 @@ class ReachabilityAnalyzer {
   void add_connection(const int src, const int dst);
   const bool is_reachable(const int src, const int dst);
 
-  size_t size() const { return size_; }
+  std::size_t size() const { return size_; }
 
  private:
-  std::vector<std::vector<int64_t>> adj_;
-  size_t num_nodes_;  // == adj_.size() == adj_[0].size()
-  size_t size_;
+  std::vector<std::vector<std::int64_t>> adj_;
+  std::size_t num_nodes_;  // == adj_.size() == adj_[0].size()
+  std::size_t size_;
 };
 
 }  // namespace devtools_python_typegraph
